@@ -1,45 +1,186 @@
+use 5.006;    # pragmas, qr
 use warnings;
 use strict;
 
 package MooseX::Has::Sugar;
-BEGIN {
-  $MooseX::Has::Sugar::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $MooseX::Has::Sugar::VERSION = '0.05070421';
-}
-
+$MooseX::Has::Sugar::VERSION = '1.000000';
 # ABSTRACT: Sugar Syntax for moose 'has' fields
 
-
-use Carp          ();
-use Sub::Exporter ();
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
-Sub::Exporter::setup_exporter(
-  {
-    as      => 'do_import',
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+use Carp ();
+use Sub::Exporter::Progressive (
+  -setup => {
     exports => [ 'ro', 'rw', 'required', 'lazy', 'lazy_build', 'coerce', 'weak_ref', 'auto_deref', 'bare', ],
     groups  => {
       isattrs => [ 'ro',       'rw',   'bare', ],
       attrs   => [ 'required', 'lazy', 'lazy_build', 'coerce', 'weak_ref', 'auto_deref', ],
-      default => [ '-attrs', '-isattrs' ],
-    }
-  }
+      default => [ 'ro',       'rw',   'bare', 'required', 'lazy', 'lazy_build', 'coerce', 'weak_ref', 'auto_deref', ],
+    },
+  },
 );
 
-sub import {
-  for (@_) {
-    if ( $_ =~ qr/^[:-]is\$/ ) {
-      Carp::croak( qq{Trivial ro/rw with :is dropped as of 0.0300.\n} . q{ See MooseX::Has::Sugar::Minimal for those. } );
-    }
-    if ( $_ =~ qr/^[:-]allattrs\$/ ) {
-      Carp::carp(q{MooseX::Has::Sugar->import(:allattrs) is deprecated. just do 'use MooseX::Has::Sugar;' instead.});
-      $_ =~ s/^[:-]allattrs\$/:default/;
-    }
-  }
-  goto &MooseX::Has::Sugar::do_import;
-}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 sub bare() {
@@ -47,57 +188,101 @@ sub bare() {
 }
 
 
+
+
+
+
+
 sub ro() {
   return ( 'is', 'ro' );
 }
 
 
+
+
+
+
+
 sub rw() {
   return ( 'is', 'rw' );
 }
 
 
+
+
+
+
+
 sub required() {
   return ( 'required', 1 );
 }
 
 
+
+
+
+
+
 sub lazy() {
   return ( 'lazy', 1 );
 }
 
 
+
+
+
+
+
 sub lazy_build() {
   return ( 'lazy_build', 1 );
 }
 
 
+
+
+
+
+
 sub weak_ref() {
   return ( 'weak_ref', 1 );
 }
 
 
+
+
+
+
+
+
+
 sub coerce() {
   return ( 'coerce', 1 );
 }
 
 
+
+
+
+
+
 sub auto_deref() {
   return ( 'auto_deref', 1 );
 }
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::Has::Sugar - Sugar Syntax for moose 'has' fields
 
 =head1 VERSION
 
-version 0.05070421
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -213,15 +398,15 @@ Or even
 
 =head1 EXPORT GROUPS
 
-=head2 :default
+=head2 C<:default>
 
-Since 0.0300, this exports all our syntax, the same as C<:attrs :isattrs>.
+Since 0.0300, this exports all our syntax, the same as C<:attrs> C<:isattrs>.
 Primarily because I found you generally want all the sugar, not just part of it.
 This also gets rid of that nasty exclusion logic.
 
-=head2 :isattrs
+=head2 C<:isattrs>
 
-This exports C<ro>, C<rw> and C<bare> as lists, so they behave as stand-alone attrs like
+This exports C<ro>, C<rw> and C<bare> as lists, so they behave as stand-alone attributes like
 L</lazy> does.
 
     has foo => (
@@ -232,7 +417,7 @@ L</lazy> does.
 
 B<NOTE: This option is incompatible with L<::Sugar::Minimal|MooseX::Has::Sugar::Minimal>> : L</CONFLICTS>
 
-=head2 :attrs
+=head2 C<:attrs>
 
 This exports L</lazy> , L</lazy_build> and L</required>, L</coerce>, L</weak_ref>
 and L</auto_deref> as subs that assume positive.
@@ -244,11 +429,11 @@ and L</auto_deref> as subs that assume positive.
 
 B<NOTE: This option is incompatible with L<MooseX::Types|MooseX::Types> and L<Moose's Type Constraints Module|Moose::Util::TypeConstraints>> : L</CONFLICTS>
 
-=head2 :is
+=head2 C<:is>
 
 B<DEPRECATED>. See L<::Sugar::Minimal|MooseX::Has::Sugar::Minimal> for the same functionality
 
-=head2 :allattrs
+=head2 C<:allattrs>
 
 B<DEPRECATED>, just use L</:default> or do
 
@@ -256,41 +441,41 @@ B<DEPRECATED>, just use L</:default> or do
 
 =head1 EXPORTED FUNCTIONS
 
-=head2 bare
+=head2 C<bare>
 
 returns C<('is','bare')>
 
-=head2 ro
+=head2 C<ro>
 
 returns C<('is','ro')>
 
-=head2 rw
+=head2 C<rw>
 
 returns C<('is','rw')>
 
-=head2 required
+=head2 C<required>
 
 returns C<('required',1)>
 
-=head2 lazy
+=head2 C<lazy>
 
 returns C<('lazy',1)>
 
-=head2 lazy_build
+=head2 C<lazy_build>
 
 returns C<('lazy_build',1)>
 
-=head2 weak_ref
+=head2 C<weak_ref>
 
 returns C<('weak_ref',1)>
 
-=head2 coerce
+=head2 C<coerce>
 
 returns C<('coerce',1)>
 
 B<WARNING:> Conflict with L<MooseX::Types|MooseX::Types> and L<Moose::Util::TypeConstraints|Moose::Util::TypeConstraints>, see L</CONFLICTS>.
 
-=head2 auto_deref
+=head2 C<auto_deref>
 
 returns C<('auto_deref',1)>
 
@@ -326,10 +511,9 @@ Kent Fredric <kentnl at cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric.
+This software is copyright (c) 2014 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
